..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

.. automodule:: invenio_theme.ext
   :members:

Bundles
-------

.. automodule:: invenio_theme.bundles
   :members:

Handlers
--------

.. automodule:: invenio_theme.views
   :members:
